import QtQuick 2.12

Rectangle {
    id: root
    property string title: "group"
    property int fontPtSize: 26
    property string savetitle: title

    color: "transparent"
    radius: 12
    state: "Normal"

    Rectangle {
        id: rootBackground
        anchors.fill: parent
        radius: root.radius
        color: "transparent"
    }

    states: [
        State {
            name: "Normal"
            PropertyChanges {
                target: titleInput
                readOnly: true
                focus: false
            }
            PropertyChanges {
                target: cleanImage
                visible: false
            }
            PropertyChanges {
                target: root
                color: "transparent"
            }
            StateChangeScript {
                script: {
                    if (titleInput.text === "") {
                        titleInput.text = root.title
                    }
                    mouseArea.visible = true
                }
            }
        },
        State {
            name: "Editable"
            PropertyChanges {
                target: titleInput
                readOnly: false
                focus: true
            }
            PropertyChanges {
                target: cleanImage
                visible: true
            }
            PropertyChanges {
                target: rootBackground
                color: "#FAFAFA"
                opacity: 0.2
            }
            StateChangeScript {
                script: {
                    mouseArea.visible = false
                }
            }
        }
    ]

    TextInput {
        id: titleInput
        font.pointSize: fontPtSize
        font.weight: Font.Medium
        font.styleName: "Noto Sans CJK SC Medium";
        text: title
        readOnly: true
        anchors.fill: parent
        maximumLength: Style.maxTitleLength
        horizontalAlignment: TextInput.AlignHCenter
        verticalAlignment: TextInput.AlignVCenter
        onEditingFinished: {
            if (text == "") {
                title = savetitle
            } else {
                title = text
            }
        }
    }
    MouseArea {
        id: mouseArea
        anchors.fill: titleInput
        pressAndHoldInterval: 300
        onPressAndHold: {
            root.state = "Editable"
        }
    }

    Image {
        id: cleanImage
        anchors.right: parent.right
        anchors.rightMargin: 30 * Style.tabletScaleFactor
        anchors.verticalCenter: parent.verticalCenter
        sourceSize: Qt.size(40, 40)
        source: "qrc:/ui/images/cleanbtn.svg"
        visible: false
        MouseArea {
            anchors.fill: parent
            onClicked: {
                titleInput.text = ""
            }
        }
    }
}
